@@ -10,18 +10,12 @@ if [ ! -d "${prefix}" ]; then
   exit
 fi
 
-#
-#  1.  Make sure there is a resolv.conf file present, such that
-#     DNS lookups succeed.
-#
-echo "  Creating resolv.conf"
-if [ ! -d "${prefix}/etc/" ]; then
-    mkdir -p "${prefix}/etc/"
-fi
-cp /etc/resolv.conf "${prefix}/etc/"
+# rpm's can now be removed
+rm -f ${prefix}/*.rpm
 
 #
-#  3.5 BUGFIX:
+#  BUGFIX:
+#
 echo "BUGFIX"
 mkdir -p ${prefix}/usr/lib/python2.4/site-packages/urlgrabber.skx
 for i in ${prefix}/usr/lib/python2.4/site-packages/urlgrabber/keepalive.*; do
@@ -29,21 +23,13 @@ for i in ${prefix}/usr/lib/python2.4/site-packages/urlgrabber/keepalive.*; do
 done
 
 #
-#  4.  Run "yum install yum".
+#  Run "yum install yum".
 #
-echo "  Mounting /proc"
-if [ ! -d "${prefix}/proc" ]; then
-    mkdir -p "${prefix}/proc"
-fi
-mount -o bind /proc ${prefix}/proc
-
 echo "  Bootstrapping yum"
-chroot ${prefix} /usr/bin/yum -y install yum         2>/dev/null
-chroot ${prefix} /usr/bin/yum -y install vim-minimal 2>/dev/null
-chroot ${prefix} /usr/bin/yum -y install dhclient    2>/dev/null
+chroot ${prefix} /usr/bin/yum -y install yum vim-minimal dhclient 2>/dev/null
 
 #
-#  4.5 make 'passwd' work.
+#  make 'passwd' work.
 #
 echo "  Authfix"
 chroot ${prefix} /usr/bin/yum -y install authconfig
@@ -55,14 +41,17 @@ chroot ${prefix} /usr/bin/authconfig --enableshadow --update
 echo "  Cleaning up"
 chroot ${prefix} /usr/bin/yum clean all
 umount ${prefix}/proc
+umount ${prefix}/sys
 
 
 #
 #  6.  Remove the .rpm files from the prefix root.
 #
 echo "  Final tidy..."
-for i in ${prefix}/*.rpm; do
-    rm -f $i
-done
 find ${prefix} -name '*.rpmorig' -delete
 find ${prefix} -name '*.rpmnew' -delete
+
+# Install modprobe
+if [ -e "${prefix}/etc/modprobe.d/modprobe.conf.dist" ]; then
+    cp  "${prefix}/etc/modprobe.d/modprobe.conf.dist" "${prefix}/etc/modprobe.conf"
+fi
