@@ -13,18 +13,6 @@ if [ ! -d "${prefix}" ]; then
 fi
 
 
-
-#
-#  1.  Make sure there is a resolv.conf file present, such that
-#     DNS lookups succeed.
-#
-echo "  Creating resolv.conf"
-if [ ! -d "${prefix}/etc/" ]; then
-    mkdir -p "${prefix}/etc/"
-fi
-cp /etc/resolv.conf "${prefix}/etc/"
-
-
 #
 #  2.  Copy the cached .RPM files into the yum directory, so that
 #     yum doesn't need to make them again.
@@ -68,7 +56,7 @@ assumeyes=1
 
 [core]
 name=core
-baseurl=http://mirror.bytemark.co.uk/fedora/linux/releases/9/Fedora/$arch/os
+baseurl=$mirror
 
 EOF
 
@@ -76,12 +64,6 @@ EOF
 #
 #  4.  Run "yum install yum".
 #
-echo "  Mounting /proc"
-if [ ! -d "${prefix}/proc" ]; then
-    mkdir -p "${prefix}/proc"
-fi
-mount -o bind /proc ${prefix}/proc
-
 echo "  Priming the yum cache"
 if [ ! -d "${prefix}/var/cache/yum/core/packages/" ]; then
     mkdir -p ${prefix}/var/cache/yum/core/packages
@@ -100,8 +82,8 @@ chroot ${prefix} /usr/bin/yum -y install dhclient    2>/dev/null
 #
 echo "  Cleaning up"
 chroot ${prefix} /usr/bin/yum clean all
-
 umount ${prefix}/proc
+umount ${prefix}/sys
 
 
 #
